# ListPoliciesResponse

The list of policies
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**authentication_policies** | [**list[Policy]**](Policy.md) | List of policies | 
**limit** | **int** | Limit of policies in the response | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


